@@ -88,6 +88,9 @@ public final class JettyConfig
     /** Felix specific property to control the maximum size of the jetty thread pool */
     public static final String FELIX_JETTY_THREADPOOL_MAX = "org.apache.felix.http.jetty.threadpool.max";
 
+    /** Felix specific property to enable the use of virtual threads in Jetty */
+    public static final String FELIX_JETTY_USE_VIRTUAL_THREADS = "org.apache.felix.http.jetty.virtualthreads.enable";
+
     /** Felix specific property to control the number of jetty acceptor threads */
     public static final String FELIX_JETTY_ACCEPTORS = "org.apache.felix.http.jetty.acceptors";
 
@@ -103,9 +106,18 @@ public final class JettyConfig
     /** Felix specific property to configure the request buffer size. Default is 24KB */
     public static final String FELIX_JETTY_RESPONSE_BUFFER_SIZE = "org.apache.felix.http.jetty.responseBufferSize";
 
-    /** Felix specific property to configure the max form size. Default is 200KB */
+    /** Felix specific property to configure the max form size. Default is 200KB. */
     public static final String FELIX_JETTY_MAX_FORM_SIZE = "org.apache.felix.http.jetty.maxFormSize";
 
+    /** Felix specific property to configure the request size limit. Default is unlimited. See https://jetty.org/docs/jetty/12/programming-guide/server/http.html#handler-use-size-limit */
+    public static final String FELIX_JETTY_REQUEST_SIZE_LIMIT = "org.apache.felix.http.jetty.requestSizeLimit";
+
+    /** Felix specific property to configure the response size limit. Default is unlimited. See https://jetty.org/docs/jetty/12/programming-guide/server/http.html#handler-use-size-limit */
+    public static final String FELIX_JETTY_RESPONSE_SIZE_LIMIT = "org.apache.felix.http.jetty.responseSizeLimit";
+
+    /** Felix specific property to configure the custom headers to add to all error pages served by Jetty. Separate key-value pairs with ##. */
+    public static final String FELIX_JETTY_ERROR_PAGE_CUSTOM_HEADERS = "org.apache.felix.http.jetty.errorPageCustomHeaders";
+
     /** Felix specific property to enable Jetty MBeans. Valid values are "true", "false". Default is false */
     public static final String FELIX_HTTP_MBEANS = "org.apache.felix.http.mbeans";
 
@@ -166,6 +178,9 @@ public final class JettyConfig
     /**  Felix specific property to configure session max age */
     public static final String FELIX_JETTY_SERVLET_SESSION_MAX_AGE = "org.eclipse.jetty.servlet.MaxAge";
 
+    /**  Felix specific property to configure the uri compliance mode (https://eclipse.dev/jetty/documentation/jetty-12/programming-guide/index.html#pg-server-compliance-uri) */
+    public static final String FELIX_JETTY_URI_COMPLIANCE_MODE = "org.eclipse.jetty.UriComplianceMode";
+
     /** Felix specific property to configure session scavenging interval in Seconds */
     public static final String FELIX_JETTY_SESSION_SCAVENGING_INTERVAL = "org.eclipse.jetty.servlet.SessionScavengingInterval";
 
@@ -268,6 +283,18 @@ public final class JettyConfig
     /** Felix specific property to specify the default protocol when negotiation fails  */
     public static final String FELIX_JETTY_ALPN_DEFAULT_PROTOCOL = "org.apache.felix.jetty.alpn.defaultProtocol";
 
+    /** Felix specific property to control whether to enable the standard jakarta.websocket APIs provided by Jakarta WebSocket 2.1 */
+    public static final String FELIX_JAKARTA_WEBSOCKET_ENABLE = "org.apache.felix.jakarta.websocket.enable";
+
+    /** Felix specific property to control whether to enable they Jetty-specific WebSocket APIs */
+    public static final String FELIX_JETTY_WEBSOCKET_ENABLE = "org.apache.felix.jetty.websocket.enable";
+
+    /** Felix specific property to control whether an OSGi configuration is required */
+    private static final String FELIX_REQUIRE_OSGI_CONFIG = "org.apache.felix.http.require.config";
+
+    /** Jetty specific property to control relative redirect handling (defaults to true) */
+    public static final String FELIX_JETTY_ALLOW_RELATIVE_REDIRECTS = "org.apache.felix.jetty.relativeredirectallowed";
+
     private static String validateContextPath(String ctxPath)
     {
         // undefined, empty, or root context path
@@ -459,6 +486,10 @@ public final class JettyConfig
         return getIntProperty(FELIX_JETTY_SELECTORS, -1);
     }
 
+    public boolean isUseVirtualThreads() {
+        return this.getBooleanProperty(FELIX_JETTY_USE_VIRTUAL_THREADS, false);
+    }
+
     public int getRequestBufferSize()
     {
         return getIntProperty(FELIX_JETTY_REQUEST_BUFFER_SIZE, 8 * 1024);
@@ -474,6 +505,20 @@ public final class JettyConfig
         return getIntProperty(FELIX_JETTY_MAX_FORM_SIZE, 200 * 1024);
     }
 
+    public int getRequestSizeLimit()
+    {
+        return getIntProperty(FELIX_JETTY_REQUEST_SIZE_LIMIT, -1);
+    }
+
+    public int getResponseSizeLimit()
+    {
+        return getIntProperty(FELIX_JETTY_RESPONSE_SIZE_LIMIT, -1);
+    }
+
+    public String getFelixJettyErrorPageCustomHeaders() {
+        return getProperty(FELIX_JETTY_ERROR_PAGE_CUSTOM_HEADERS, null);
+    }
+
     /**
      * Returns the configured session timeout in minutes or zero if not
      * configured.
@@ -674,6 +719,22 @@ public final class JettyConfig
         return getLongProperty(FELIX_JETTY_STOP_TIMEOUT, -1l);
     }
 
+    /**
+     * Returns <code>true</code> if jakarta websocket is configured to be used (
+     * {@link #FELIX_JAKARTA_WEBSOCKET_ENABLE})
+     */
+    public boolean isUseJakartaWebsocket() {
+        return getBooleanProperty(FELIX_JAKARTA_WEBSOCKET_ENABLE, false);
+    }
+
+    /**
+     * Returns <code>true</code> if jetty websocket is configured to be used (
+     * {@link #FELIX_JETTY_WEBSOCKET_ENABLE})
+     */
+    public boolean isUseJettyWebsocket() {
+        return getBooleanProperty(FELIX_JETTY_WEBSOCKET_ENABLE, false);
+    }
+
     public void reset()
     {
         update(null);
@@ -941,4 +1002,8 @@ public final class JettyConfig
             return dflt;
         }
     }
+
+    public boolean isRequireConfiguration() {
+        return this.getBooleanProperty(FELIX_REQUIRE_OSGI_CONFIG, false);
+    }
 }
